@@ -522,7 +522,7 @@ int NeighborCellLocator::GetFullNeighborsQuery(Vec &position, int *neighbors, Ve
                           int& nb_size, double r) const
 {
   if (invalid)
-    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.");
+    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") << __LINE__;
 
   const vector<Vec> &RESTRICT positions = GetWrappedPositions();
   // Need to use GET_CELL instead of GetCell as the atoms are not open
@@ -703,7 +703,7 @@ int NeighborCellLocator::CommonGetNeighbors(int a1, int *RESTRICT neighbors, Vec
 					    double r, bool wantfull) const
 {
   if (invalid)
-    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.");
+    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.")  << __LINE__;
 
   const vector<Vec> &RESTRICT positions = GetWrappedPositions();
   // Need to use GET_CELL instead of GetCell as the atoms are not open
@@ -770,7 +770,7 @@ void NeighborCellLocator::CommonGetNeighbors(int a1, vector<int> &neighbors,
 					     bool wantfull) const
 {
   if (invalid)
-    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.");
+    throw AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") << __LINE__;
   
   const vector<Vec> &positions_x = GetWrappedPositions();
   const Vec *RESTRICT superCell = atoms->GET_CELL();
@@ -830,7 +830,7 @@ int NeighborCellLocator::GetListAndTranslations(int a1,
        vector<neighboritem_t> &neighbors) const
 {
   if (invalid)
-    THROW( AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") );
+    THROW( AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") << __LINE__);
   RETURNIFASAPERROR2(0);
   
   const vector<Vec> &positions = GetWrappedPositions();
@@ -881,7 +881,7 @@ int NeighborCellLocator::GetComplementaryListAndTranslations(int a1,
 {
   RETURNIFASAPERROR2(0);
   if (invalid)
-    THROW( AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") );
+    THROW( AsapError("NeighborCellLocator has been invalidated, possibly by another NeighborList using the same atoms.") << __LINE__ );
   
   const vector<Vec> &positions = GetWrappedPositions();
   const Vec *superCell = atoms->GetCell();
