@@ -363,6 +363,16 @@ bool OpenKIMcalculator::CalcReq_Virials(PyObject *pyatoms)
   return required;
 }
 
+bool OpenKIMcalculator::CheckAndUpdateNbList(PyObject *pyatoms)
+{
+  atoms->Begin(pyatoms);
+  bool update = CheckNeighborList();
+  if (update)
+    UpdateNeighborList();
+  atoms->End();
+  return update;
+}
+
 bool OpenKIMcalculator::CheckNeighborList()
 {
   RETURNIFASAPERROR2(false);
