@@ -45,6 +45,17 @@ public:
 
 // #define REGARRAYINFO   // Print extra debugging info about reg. arrays.
 
+// Local function to get stride from PyArray, even if first dimension is zero
+// (PyArray_STRIDE returns 0 in that case for numpy version 1.23.X)
+static npy_intp get_stride_from_array(PyArrayObject *arr)
+{
+  npy_intp stride = PyArray_ITEMSIZE(arr);
+  for (int i = 1; i < PyArray_NDIM(arr); i++)
+    stride *= PyArray_DIM(arr, i);
+  ASSERT(PyArray_STRIDE(arr, 0) == 0 || PyArray_STRIDE(arr, 0) == stride);
+  return stride;
+}
+
 /////////////////////////////
 ////
 ////  CONSTRUCTOR
@@ -277,7 +288,7 @@ void ParallelAtoms::Migrate(bool distributing /* = false */)
   int nBytes = 0;   // Number of bytes to be communicated per atom.
   for (vector<PyArrayObject *>::const_iterator arr = arrays.begin();
        arr < arrays.end(); ++arr)
-    nBytes += PyArray_STRIDE(*arr, 0);
+    nBytes += get_stride_from_array(*arr);
 
   receiveBuffer.resize(0);
   int nCommunicate = sendlist->size();
@@ -297,7 +308,7 @@ void ParallelAtoms::Migrate(bool distributing /* = false */)
 	  for (vector<PyArrayObject *>::const_iterator arr = arrays.begin();
 	       arr < arrays.end(); ++arr)
 	    {
-	      long stride = PyArray_STRIDE(*arr, 0);
+	      long stride = get_stride_from_array(*arr);
 	      memcpy(b, PyArray_BYTES(*arr) + a * stride, stride);
 	      b += stride;
 	    }
@@ -342,7 +353,7 @@ void ParallelAtoms::Migrate(bool distributing /* = false */)
 	{
 	  for (int j = 0; j < arrays.size(); j++)
 	    {
-	      long stride = PyArray_STRIDE(arrays[j], 0);
+	      long stride = get_stride_from_array(arrays[j]);
 	      memcpy(PyArray_BYTES(new_arrays[j]) + target * stride,
 		     PyArray_BYTES(arrays[j]) + a1 * stride,
 		     n * stride);
@@ -362,7 +373,7 @@ void ParallelAtoms::Migrate(bool distributing /* = false */)
     {
       for (int j = 0; j < new_arrays.size(); j++)
 	{
-	  long stride = PyArray_STRIDE(new_arrays[j], 0);
+	  long stride = get_stride_from_array(new_arrays[j]);
 	  memcpy(PyArray_BYTES(new_arrays[j]) + a * stride, b, stride);
 	  b += stride;
 	}
@@ -633,8 +644,8 @@ void ParallelAtoms::UpdateGhostData()
   // Count number of bytes and find the positions array.
   for (int i = 0; i < array_names.size(); i++)
     {
-      int n = PyArray_STRIDE(real_arrays[i], 0);
-      ASSERT(PyArray_STRIDE(ghost_arrays[i], 0) == n);
+      int n = get_stride_from_array(real_arrays[i]);
+      ASSERT(get_stride_from_array(ghost_arrays[i]) == n);
       ASSERT(PyArray_DIM(real_arrays[i], 0) == nAtoms);
       ASSERT(PyArray_DIM(ghost_arrays[i], 0) == nGhosts);
       nBytes += n;
@@ -665,10 +676,11 @@ void ParallelAtoms::UpdateGhostData()
 	  typedef vector< pair<int, int> >::const_iterator VP;
 	  for (VP g = indices.begin(); g != indices.end(); ++g)
 	    {
+	      npy_intp stride = get_stride_from_array(real_arrays[arr]);
 	      char *from = PyArray_BYTES(real_arrays[arr]) +
-		((long)g->first) * PyArray_STRIDE(real_arrays[arr], 0);
-	      memcpy(b, from, PyArray_STRIDE(real_arrays[arr], 0));
-	      b += PyArray_STRIDE(real_arrays[arr], 0);
+		((long)g->first) * stride;
+	      memcpy(b, from, stride);
+	      b += stride;
 	    }
 	}
       ASSERT(b - &sendBuffer[0] == sendBuffer.size());
@@ -683,10 +695,10 @@ void ParallelAtoms::UpdateGhostData()
       b = &recvBuffer[0];
       for (int arr = 0; arr < array_names.size(); arr++)
 	{
-	  char *to = PyArray_BYTES(ghost_arrays[arr])
-	    + offset * PyArray_STRIDE(ghost_arrays[arr], 0);
-	  memcpy(to, b, n_recv * PyArray_STRIDE(ghost_arrays[arr], 0));
-	  b += n_recv * PyArray_STRIDE(ghost_arrays[arr], 0);
+	  npy_intp stride = get_stride_from_array(ghost_arrays[arr]);
+	  char *to = PyArray_BYTES(ghost_arrays[arr]) + offset * stride;
+	  memcpy(to, b, n_recv * stride);
+	  b += n_recv * stride;
 	}
       offset += n_recv;
       mpi->Wait();
