@@ -27,6 +27,7 @@ md.run(steps=5000)
 # every 5 steps
 temp = []
 energy = []
+com = a.get_center_of_mass()
 for i in range(2000):
     md.run(steps=5)
     temp.append(a.get_temperature())
@@ -37,5 +38,9 @@ fluct = np.std(temp)
 avgenergy = np.mean(energy)
 print("Temperature is {:.2f} K +/- {:.2f} K".format(avgtemp, fluct))
 ReportTest("Average temperature", avgtemp, T, 10.0)
+
+delta = np.linalg.norm(a.get_center_of_mass() - com)
+ReportTest("Change in center of mass", delta, 0.0, 1e-9)
+
 ReportTest.Summary()
 
