@@ -13,7 +13,7 @@ if OpenKIMsupported:
         calc = OpenKIMcalculator(model)
     except AsapError as oops:
         if oops.args[0].startswith('Failed to initialize OpenKIM model'):
-            print("OpenKIM model {} not installed - skipping test.".format(openkimmodel))
+            print("OpenKIM model {} not installed - skipping test.".format(model))
             calc = None
         else:
             raise
